@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "klondike" "1.2.0"
+(define-package "klondike" "20250301.2336"
   "Klondike."
   '((emacs "28.1"))
   :url "https://codeberg.org/tomenzgg/Emacs-Klondike"
-  :commit "50315bbb341f74e0ecc23e66757bbfa4a8cacb50"
-  :revdesc "50315bbb341f"
+  :commit "891cc54c1d9411f7848a4bba34811370ae19960e"
+  :revdesc "891cc54c1d94"
   :keywords '("games" "cards" "solitaire" "klondike")
   :authors '(("Jean Libète" . "tomenzgg@mail.mayfirst.org"))
   :maintainers '(("Jean Libète" . "tomenzgg@mail.mayfirst.org")))
