@@ -5,8 +5,8 @@
 ;; Author: Jean Libète <tomenzgg@mail.mayfirst.org>
 ;; URL: https://codeberg.org/tomenzgg/Emacs-Klondike
 ;; Package-Requires: ((emacs "28.1"))
-;; Package-Version: 1.2.0
-;; Package-Revision: 50315bbb341f
+;; Package-Version: 20250301.2336
+;; Package-Revision: 891cc54c1d94
 ;; Keywords: games, cards, solitaire, klondike
 
 ;; This program is free software; you can redistribute it and/or modify
@@ -30,8 +30,6 @@
 ;; cl-case
 ;; cl-evenp
 (require 'cl-lib)
-;; pcase
-(require 'pcase)
 ;; if-let*
 (require 'subr-x)
 ;; run-at-time
@@ -491,8 +489,9 @@ made visible."
                                                           1card+padding
                                                           additional))))
          (move-to             (lambda (w z &optional additional)
-                                (funcall-interactively #'goto-line z)
-                                (move-to-column                    w)
+                                (goto-char      0)
+                                (forward-line   z)
+                                (move-to-column w)
 
                                 (funcall delete-reg (if additional additional 0))))
          (cardHeightW/oTopBot (- klondike-card-height 2))
@@ -732,9 +731,9 @@ made visible."
                                 (1+ offset)))
             (insert (make-string 1card+padding ? )))))))
 
-  (read-only-mode                    t)
-  (funcall-interactively #'goto-line 0)
-  (move-to-column                    1)
+  (read-only-mode           t)
+  (goto-char      (point-min))
+  (move-to-column           1)
 
   (setq klondike---mode-line-status (klondike--compute-modeline)))
 (defun klondike--card-insert-all (&optional stacks-to-print)
@@ -781,13 +780,14 @@ each card."
 
   (let ((totalNum (length (klondike--stack-get-cards stack))))
     (dotimes (stackIndex (klondike--stack-get-visible stack))
-      (funcall-interactively #'goto-line (+ (if (zerop stackIndex) 1 0)
-                                            (klondike--stack-get-y stack)
-                                            (- totalNum stackIndex)))
-      (move-to-column                    (+ (if (zerop stackIndex) 1 0)
-                                            (klondike--stack-get-x stack)
-                                            (- totalNum            (1+ stackIndex))
-                                            (- klondike-card-width 4)))
+      (goto-char      0)
+      (forward-line   (+ (if (zerop stackIndex) 1 0)
+                         (klondike--stack-get-y stack)
+                         (- totalNum stackIndex)))
+      (move-to-column (+ (if (zerop stackIndex) 1 0)
+                         (klondike--stack-get-x stack)
+                         (- totalNum            (1+ stackIndex))
+                         (- klondike-card-width 4)))
 
       (delete-region (point) (+ (point) 2))
 
@@ -797,9 +797,10 @@ each card."
                   "")
                 (propertize result 'face 'klondike-stack-numbering)))))
 
-  (read-only-mode                    t)
-  (funcall-interactively #'goto-line 0)
-  (move-to-column                    1))
+  (read-only-mode t)
+  (goto-char      0)
+  (forward-line   0)
+  (move-to-column 1))
 (defun klondike--stack-number-select (stack selected-num &optional hide-stack-p)
   "Highlght the SELECTED-NUM of the visible waste cards in STACK.
 
@@ -813,15 +814,16 @@ SELECTED-NUM."
 
   (let ((  totalNum (if hide-stack-p 1 (length (klondike--stack-get-cards stack))))
         (visibleNum (klondike--stack-get-visible stack)))
-    (funcall-interactively #'goto-line (+ (if (= selected-num 1) 1 0)
-                                          (klondike--stack-get-y stack)
-                                          (- totalNum        visibleNum)  ; stocks
-                                          (- (1+ visibleNum) selected-num)))
-    (move-to-column                    (+ (if (= selected-num 1) 1 0)
-                                          (klondike--stack-get-x stack)
-                                          (-   totalNum            visibleNum)
-                                          (- visibleNum          selected-num)
-                                          (- klondike-card-width            4)))
+    (goto-char      0)
+    (forward-line   (+ (if (= selected-num 1) 1 0)
+                       (klondike--stack-get-y stack)
+                       (- totalNum        visibleNum)  ; stocks
+                       (- (1+ visibleNum) selected-num)))
+    (move-to-column (+ (if (= selected-num 1) 1 0)
+                       (klondike--stack-get-x stack)
+                       (-   totalNum            visibleNum)
+                       (- visibleNum          selected-num)
+                       (- klondike-card-width            4)))
 
     (delete-region (point) (+ (point) 2))
 
@@ -831,9 +833,10 @@ SELECTED-NUM."
                 "")
               (propertize stringNum 'face 'klondike-stack-selecting))))
 
-  (read-only-mode                    t)
-  (funcall-interactively #'goto-line 0)
-  (move-to-column                    1))
+  (read-only-mode t)
+  (goto-char      0)
+  (forward-line   0)
+  (move-to-column 1))
 (defun klondike--stack-clear-selects (stack &optional hide-stack-p)
   "Wipe out all numbering of the visible waste cards of STACK.
 
@@ -844,21 +847,23 @@ select in the stack is 1."
 
   (let ((totalNum (if hide-stack-p 1 (length (klondike--stack-get-cards stack)))))
     (dotimes (stackIndex (klondike--stack-get-visible stack))
-      (funcall-interactively #'goto-line (+ (if (zerop stackIndex) 1 0)
-                                            (klondike--stack-get-y stack)
-                                            (- totalNum stackIndex)))
-      (move-to-column                    (+ (if (zerop stackIndex) 1 0)
-                                            (klondike--stack-get-x stack)
-                                            (- totalNum            (1+ stackIndex))
-                                            (- klondike-card-width 4)))
+      (goto-char      0)
+      (forward-line   (+ (if (zerop stackIndex) 1 0)
+                         (klondike--stack-get-y stack)
+                         (- totalNum stackIndex)))
+      (move-to-column (+ (if (zerop stackIndex) 1 0)
+                         (klondike--stack-get-x stack)
+                         (- totalNum            (1+ stackIndex))
+                         (- klondike-card-width 4)))
 
       (delete-region (point) (+ (point) 2))
 
       (insert (if (zerop stackIndex) "  " "──"))))
 
-  (read-only-mode                    t)
-  (funcall-interactively #'goto-line 0)
-  (move-to-column                    1))
+  (read-only-mode t)
+  (goto-char      0)
+  (forward-line   0)
+  (move-to-column 1))
 
 
 
@@ -1257,7 +1262,7 @@ to the stock stack and in the facedown position."
 
                             mode-map)
   "Keymap for `klondike-mode'.")
-(define-derived-mode klondike-mode fundamental-mode "Klondike"
+(define-derived-mode klondike-mode special-mode "Klondike"
   "Major mode for the Klondike solitaire game for Emacs."
 
   (when-let ((stack-type (car klondike---stack-pick-stack)))
@@ -1426,7 +1431,8 @@ If one is already being played, switch to the active buffer."
                            6
                            topBotPadding
                            20))
-        (funcall-interactively #'goto-line (1+ lineNum))
+        (goto-char    0)
+        (forward-line (1+ lineNum))
 
         (insert (make-string (+ klondike-window-padding
                                 (* 8 1card+padding))     ? ) "\n"))
